@@ -32,7 +32,7 @@ var NAVTREE =
       [ "Installing the binaries on Windows", "install.html#install_bin_windows", null ]
     ] ],
     [ "Getting started", "starting.html", [
-      [ "Step 0: Check if doxygen supports your programming language", "starting.html#step0", null ],
+      [ "Step 0: Check if doxygen supports your programming/hardware description language", "starting.html#step0", null ],
       [ "Step 1: Creating a configuration file", "starting.html#step1", null ],
       [ "Step 2: Running doxygen", "starting.html#step2", [
         [ "HTML output", "starting.html#html_out", null ],
@@ -210,6 +210,7 @@ var NAVTREE =
       [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
       [ "\\showrefs", "commands.html#cmdshowrefs", null ],
       [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
+      [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
       [ "\\concept <name>", "commands.html#cmdconcept", null ],
@@ -221,12 +222,14 @@ var NAVTREE =
       [ "\\endinternal", "commands.html#cmdendinternal", null ],
       [ "\\extends <name>", "commands.html#cmdextends", null ],
       [ "\\file [<name>]", "commands.html#cmdfile", null ],
+      [ "\\fileinfo['{'option'}']", "commands.html#cmdfileinfo", null ],
+      [ "\\lineinfo", "commands.html#cmdlineinfo", null ],
       [ "\\fn (function declaration)", "commands.html#cmdfn", null ],
       [ "\\headerfile <header-file> [<header-name>]", "commands.html#cmdheaderfile", null ],
       [ "\\hideinitializer", "commands.html#cmdhideinitializer", null ],
       [ "\\idlexcept <name>", "commands.html#cmdidlexcept", null ],
       [ "\\implements <name>", "commands.html#cmdimplements", null ],
-      [ "\\ingroup (<groupname> [<groupname> <groupname>])", "commands.html#cmdingroup", null ],
+      [ "\\ingroup (<groupname> [<groupname>]*)", "commands.html#cmdingroup", null ],
       [ "\\interface <name> [<header-file>] [<header-name>]", "commands.html#cmdinterface", null ],
       [ "\\internal", "commands.html#cmdinternal", null ],
       [ "\\mainpage [(title)]", "commands.html#cmdmainpage", null ],
@@ -266,6 +269,7 @@ var NAVTREE =
       [ "\\cond [(section-label)]", "commands.html#cmdcond", null ],
       [ "\\copyright { copyright description }", "commands.html#cmdcopyright", null ],
       [ "\\date { date description }", "commands.html#cmddate", null ],
+      [ "\\showdate \"<format>\" [ <date_time> ]", "commands.html#cmdshowdate", null ],
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
       [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
@@ -302,7 +306,7 @@ var NAVTREE =
       [ "\\todo { paragraph describing what is to be done }", "commands.html#cmdtodo", null ],
       [ "\\version { version number }", "commands.html#cmdversion", null ],
       [ "\\warning { warning message }", "commands.html#cmdwarning", null ],
-      [ "\\xrefitem <key> \"(heading)\" \"(list title)\" { text }", "commands.html#cmdxrefitem", null ],
+      [ "\\xrefitem <key> \"heading\" \"list title\" { text }", "commands.html#cmdxrefitem", null ],
       [ "\\addindex (text)", "commands.html#cmdaddindex", null ],
       [ "\\anchor <word>", "commands.html#cmdanchor", null ],
       [ "\\cite <label>", "commands.html#cmdcite", null ],
@@ -399,7 +403,10 @@ var NAVTREE =
       [ "\\--", "commands.html#cmdndash", null ],
       [ "\\---", "commands.html#cmdmdash", null ]
     ] ],
-    [ "HTML Commands", "htmlcmds.html", null ],
+    [ "HTML Commands", "htmlcmds.html", [
+      [ "HTML tag commands", "htmlcmds.html#htmltagcmds", null ],
+      [ "HTML4 character entities", "htmlcmds.html#htmlentities", null ]
+    ] ],
     [ "XML Commands", "xmlcmds.html", null ],
     [ "Emoji support", "emojisup.html", [
       [ "Representation", "emojisup.html#emojirep", null ],
@@ -418,6 +425,9 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.6", "changelog.html#log_1_9_6", null ],
+        [ "Release 1.9.5", "changelog.html#log_1_9_5", null ],
+        [ "Release 1.9.4", "changelog.html#log_1_9_4", null ],
         [ "Release 1.9.3", "changelog.html#log_1_9_3", null ],
         [ "Release 1.9.2", "changelog.html#log_1_9_2", null ],
         [ "Release 1.9.1", "changelog.html#log_1_9_1", null ],
@@ -464,7 +474,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"config.html#config_dot"
+"commands.html#cmdxmlinclude"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
